@@ -4,20 +4,22 @@ import argparse
 import logging
 import datetime
 import itertools
+from typing import Optional
 
 from pathlib import Path
 
 import dateutil.parser
 import pytz
+import requests
 
-from .twitter import read_twitter_json, simplify_tweet
+from .tweet import Tweet
 from .pdf import PDFDocument
+from .settings import ENCODING, LANGUAGE, FONT_FAMILY, FONT_SIZE, FONT, IMAGE_WIDTH
 
 DESCRIPTION = """
 Parse Twitter archived JSON files and convert to PDF files
 """
 
-DEFAULT_FONT = './font/DejaVuSans.ttf'
 
 logger = logging.getLogger(__name__)
 
@@ -41,7 +43,7 @@ def get_args():
 
     # Twitter archive options
     parser.add_argument("-f", "--file", type=Path, dest="filename", help="Path to Twitter JSON archive", required=True)
-    parser.add_argument('--encoding', default='utf-8', help='Input file character set')
+    parser.add_argument('--encoding', default=ENCODING, help='Input file character set')
     parser.add_argument("-a", "--hashtags", help="Filter by hashtags (comma-separated list)", default=str())
     parser.add_argument("-s", "--date_start", dest="date_start", type=utc_timestamp)
     parser.add_argument("-e", "--date_end", dest="date_end", type=utc_timestamp)
@@ -51,14 +53,14 @@ def get_args():
     # PDF output options
     parser.add_argument("-p", "--pdf", type=Path, help='Output PDF file path', required=True)
     parser.add_argument('-i', '--images', help='Download images and put in the PDF document (SLOW)', action='store_true')
-    parser.add_argument('-w', '--imgwidth', help="Image width", default=150)
+    parser.add_argument('-w', '--imgwidth', help="Image width", default=IMAGE_WIDTH)
     
     # Font options
-    parser.add_argument('--font', help='Unicode font TTF file', type=Path, default=Path(DEFAULT_FONT))
-    parser.add_argument('--font_family', default='DejaVu Sans')
-    parser.add_argument('--font_size', type=float, default=11)
+    parser.add_argument('--font', help='Unicode font TTF file', type=Path, default=FONT)
+    parser.add_argument('--font_family', default=FONT_FAMILY)
+    parser.add_argument('--font_size', type=float, default=FONT_SIZE)
     parser.add_argument('--loglevel', default='INFO', help="Verbosity level: DEBUG, INFO, WARNING, ERROR")
-    parser.add_argument('--language', default='en', help='Language ISO 639-1 code')
+    parser.add_argument('--language', default=LANGUAGE, help='Language ISO 639-1 code')
 
     return parser.parse_args()
 
@@ -72,39 +74,47 @@ def main():
 
     pdf = PDFDocument(font=options.font, font_family=options.font_family, font_size=options.font_size)
 
+    # Create a HTTP session if we want to download images
+    session: Optional[requests.Session] = None
+    if options.images:
+        session = requests.Session()
+
     # Iterate over input tweets
     tweet_count = 0
-    for i, tweet in itertools.islice(enumerate(read_twitter_json(options.filename, encoding=options.encoding)), options.start, options.stop):
+    for tweet_data in itertools.islice(Tweet.load(options.filename, encoding=options.encoding), options.start, options.stop):
         tweet_count += 1
 
         # Show progress
         if tweet_count % 1000 == 0:
             logger.info(f"Processing tweet {tweet_count}")
-        logger.debug(tweet)
 
         # Decode tweet in a simple structure
-        tweet_simple = simplify_tweet(tweet, language=options.language)
+        tweet = Tweet(tweet_data)
 
         # Time filter
         try:
-            if tweet_simple['created_at'] < options.date_start:
+            if tweet.created_at < options.date_start:
                 continue
         except TypeError:
             pass
+
         try:
-            if tweet_simple['created_at'] >= options.date_end:
+            if tweet.created_at >= options.date_end:
                 continue
         except TypeError:
             pass
 
         # Filter by hashtag
-        if not tweet_simple['hashtags'].union(hashtag_filter):
+        if not tweet.hashtags.union(hashtag_filter):
             continue
 
-        pdf.add_tweet(tweet_simple, download_images=options.images, image_width=options.imgwidth)
+        pdf.add_tweet(tweet, download_images=options.images, image_width=options.imgwidth, session=session)
 
     pdf.output(options.pdf)
 
+    if session is not None:
+        session.close()
+
 
 if __name__ == '__main__':
     main()
